<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Uses to display the help information about the module with links.
 */
class CnPFormsHelp extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cnpformshelp_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    return $this->displayHelp($form, $form_state);
  }

  /**
   * Display module help information with user manual links.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure.
   */
  public function displayHelp(array $form, $form_state) {
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading">',
      '#suffix' => '</div>',
    ];
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>
                                          <li><a class="cnpccurrent" href="cnp_form_help">' . $this->t("Click & Pledge") . '</a></li>
                                          <li><a href="cnp_form">' . $this->t("Form Groups") . '</a></li>
      <li><a href="cnppledgetvchannels">pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></a></li>
                                          <li><a href="cnp_formssettings">' . $this->t("Settings") . '</a></li>
                                          </ul>',
      '#suffix' => '</div>',
    ];
    $html = '<div class="cnpc_information">
            <div class="instructions">
                <p>' . $this->t("For quick start, follow these instructions") . '</p>
                <ol>
                    <li>Go to <a href="cnp_formssettings">Settings</a> page and add Click &amp; Pledge Account Number, Account GUID and Nickname. Find Account GUID in your Click &amp; Pledge CONNECT portal. Find out <a href="https://support.clickandpledge.com/s/article/how-to-locate-account-id--api-account-guid" target="_blank"> how</a>.</li>
                    <li>Once the Account information is added, additional item (Click & Pledge) will appear on the left menu that allows you to add <a href="add_form_group"><b>Form</b></a> and <a href="add_channel_group"><b>pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></b></a> "Channel Groups"</li>
                    <li>After saving the Form Group details, a new table will appear on the same page where you may select one or more forms/TVchannels from different campaigns. <br><small><strong>Note:</strong> All campaigns and forms are retrieved from <a href="https://connect.clickandpledge.com/" target="_blank">Click &amp; Pledge CONNECT</a>.</small></li>
                </ol>
                <p>For step by step guide follow our manual <a href="https://manual.clickandpledge.com/Click-Pledge-Connect-Module-2.html" target="_blank">here</a></p>
            </div>
      </div>';
    $form['display_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // This form does not handles any data to save or update.
  }

}
