<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Path\CurrentPathStack;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * To view all the forms under a channel.
 */
class ViewChannels extends FormBase {

  /**
   * The Connection.
   *
   * @var mixed
   */
  protected $connection;

  /**
   * To get the path.
   *
   * @var mixed
   */
  protected $path;

  /**
   * The Class Constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The Database Connection.
   * @param \Drupal\Core\Path\CurrentPathStack $pathStack
   *   Represents the current path for the current request.
   */
  public function __construct(Connection $connection, CurrentPathStack $pathStack) {
    $this->connection = $connection;
    $this->path = $pathStack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'), $container->get('path.current')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cnpcaccount_viewchannels';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = $this->displayAccountSettingsForm($form, $form_state);
    return $form;
  }

  /**
   * Creates a table to display the campaign forms under channel group.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure.
   */
  public function displayAccountSettingsForm(array $form, $form_state) {
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ['id' => 'base_url_cnpc'],
    ];
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>
                  <li><a href="../cnp_form_help">' . $this->t("Click & Pledge") . '</a></li>
                  <li><a href="../cnp_form">' . $this->t("Form Groups") . '</a></li>
      <li><a class="cnpccurrent" href="../cnppledgetvchannels">pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></a></li>
                  <li><a href="../cnp_formssettings">' . $this->t("Settings") . '</a></li>
                  </ul>',
      '#suffix' => '</div>',
    ];
    $path = $this->path->getPath();
    $arg = explode('/', $path);
    $reqID = end($arg);
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channeldtl';
    $sql = "SELECT cnpchannel_id,cnpchannel_cnpchannelgrp_ID,cnpchannel_channelName,cnpchannel_channelStartDate,"
      . "cnpchannel_channelEndDate,cnpchannel_channelStatus,cnpchannel_DateCreated,"
      . "cnpchannel_DateModified FROM " . $table_name . " where cnpchannel_cnpchannelgrp_ID=" . $reqID;
    $query = $this->connection->query($sql);
    $allForms = $query->fetchAll();
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $html = '<a href="../cnppledgetvchannels" class="cnpc_button_link_edit">' . $this->t("Go back to Channel Groups") . '</a>';
    $form['gobackbtn_link_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    $form['table_group_start'] = [
      "#prefix" => "<div class='tablelist_group'>",
    ];
    if (count($allForms) > 0) {
      $form['table_tag_start'] = [
        '#prefix' => '<div><table id="table_viewforms" class="table_viewforms">
                            <thead>
                                <tr>
                                                    <th>' . $this->t('ID') . '</th>
                                                    <th>' . $this->t('Channel Name') . '</th>
                                                    <th>' . $this->t('Start Date/Time') . '</th>
                                                    <th>' . $this->t('End Date/Time') . '</th>
                                </tr>
                            </thead>
                                            <tbody>',
      ];
      $rg = 1;
      foreach ($allForms as $fg) {
        if ($fg->cnpchannel_channelEndDate == '0000-00-00 00:00:00') {
          $enddate = '';
        }
        else {
          $enddate = date('F d, Y h:i:s a', strtotime($fg->cnpchannel_channelEndDate));
        }
        $form['table_row_form_groups_' . $rg] = [
          '#prefix' => '<tr>
                                                                 <td>' . $fg->cnpchannel_id . '</td>
                                                                 <td>' . $fg->cnpchannel_channelName . '</td>
                                                                 <td>' . date('F d, Y h:i:s a', strtotime($fg->cnpchannel_channelStartDate)) . '</td>
                                                                 <td>' . $enddate . '</td>',
          '#suffix' => '</tr>',
        ];
        $rg++;
      }
      $form['table_tag_end'] = [
        '#suffix' => '</tbody></table></div>',
      ];
    }
    else {
      $form['no_records'] = [
        '#prefix' => '<div><p>' . $this->t('No Records Found.') . '</p>',
        '#suffix' => '</div>',
      ];
    }
    $form['table_group_end'] = [
      '#suffix' => '</div>',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // This class is for displaying the forms list under a channel group.
  }

}
